//---------------------------------------------------------------------------

#include <vcl.h>
#pragma hdrstop
#include <assert.h>

#include "Global2.h"
#include "UpdateSelectDlgs.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma resource "*.dfm"
TUpdateSelectDlg *UpdateSelectDlg;
//---------------------------------------------------------------------------

bool __fastcall GetUpdateSelections(TQSStatsWin4 *Owner, AnsiString &PSource, TStrings *PPages,
   AnsiString &QSource, TStrings *QPages, const AnsiString &URLFileName)
{
   assert(PPages != NULL && QPages != NULL && URLFileName != "");

   PPages->Clear();
   QPages->Clear();

   bool ok = false;
   TCheckListBox *lb;

   UpdateSelectDlg = new TUpdateSelectDlg(Owner, URLFileName);
   StrToFont(Owner->DlgsFontStr, UpdateSelectDlg->Font);
   TColor color = Owner->WindowColor;
   UpdateSelectDlg->QuickBox->Color = color;
   UpdateSelectDlg->QuickListBox->Color = color;
   UpdateSelectDlg->SourceBox->Color = color;
   UpdateSelectDlg->PageListBox->Color = color;

   UpdateSelectDlg->ShowModal();

   if (UpdateSelectDlg->ModalResult == mrOk)
   {
      PSource = UpdateSelectDlg->SourceBox->Text;
      lb = UpdateSelectDlg->PageListBox;
      for (int i = 0; i < lb->Items->Count; i++)
      {
         AnsiString item = lb->Items->Strings[i];
         if (lb->Checked[i] && item != "type2.list")
            PPages->Add(item);
      }

      QSource = UpdateSelectDlg->QuickBox->Text;
      lb = UpdateSelectDlg->QuickListBox;
      for (int i = 0; i < lb->Items->Count; i++)
      {
         if (lb->Checked[i])
            QPages->Add(lb->Items->Strings[i]);
      }

      ok = true;
   }
   delete UpdateSelectDlg;

   return ok;
}
//---------------------------------------------------------------------------

__fastcall TUpdateSelectDlg::TUpdateSelectDlg(TComponent* Owner)
   : TForm(Owner)
{
}
//---------------------------------------------------------------------------

__fastcall TUpdateSelectDlg::TUpdateSelectDlg(TComponent* Owner,
   const AnsiString &URLFile)
   : TForm(Owner)
{
   assert(URLFile != "");
   MixmasterDir = MixDir();
   assert(MixmasterDir != "");

   URLFileName = URLFile;
   LoadSources();
   LoadURLs(SourceBox->Text, PageListBox->Items);
   LoadURLs(QuickBox->Text, QuickListBox->Items);
}
//---------------------------------------------------------------------------

__fastcall TUpdateSelectDlg::~TUpdateSelectDlg()
{
}
//---------------------------------------------------------------------------

void __fastcall TUpdateSelectDlg::LoadSources()
{
   SourceBox->Items->Clear();

   TStringList *URLs = new TStringList();
   if (FileExists(URLFileName))
      URLs->LoadFromFile(URLFileName);

   int i = 0; while (i < URLs->Count)
   {
      AnsiString URL = URLs->Strings[i].Trim();
      if (URL.Pos("[") == 1 && URL.LowerCase() != "[quicksilver]")
         SourceBox->Items->Add(URL.SubString(2, URL.Length() - 2));
      i++;
   }
   SourceBox->ItemIndex = 0;

   delete URLs;
}
//---------------------------------------------------------------------------

void __fastcall TUpdateSelectDlg::LoadURLs(const AnsiString &Source, TStrings *URLs)
{
   URLs->Clear();

   TStringList *urlfile = new TStringList();
   if (FileExists(URLFileName))
      urlfile->LoadFromFile(URLFileName);

   int i = 0; while (i < urlfile->Count)
   {
      AnsiString URL = urlfile->Strings[i].Trim();
      if (URL.Pos("[" + Source + "]") == 1)
      {
         while (++i < urlfile->Count)
         {
            AnsiString line = urlfile->Strings[i].Trim();
            if (line.IsEmpty() || line.Pos("[") == 1)
               break;

            if (line.Pos(" ") > 0)
               URLs->Add(GetTok(0, line, ' '));
         }
      }
      i++;
   }

   delete urlfile;
}
//---------------------------------------------------------------------------

void __fastcall TUpdateSelectDlg::SourceBoxChange(TObject *)
{
   PageListBox->Clear();
   Snooze(200);
   LoadURLs(SourceBox->Text, PageListBox->Items);
}
//---------------------------------------------------------------------------

void __fastcall TUpdateSelectDlg::QuickBoxChange(TObject *)
{
   QuickListBox->Clear();
   Snooze(200);
   LoadURLs(QuickBox->Text, QuickListBox->Items);
}
//---------------------------------------------------------------------------

